###########################################################
### Ch5 - Script 1 - Legume tree
###########################################################

###########################################################
### Packages
###########################################################
library(rotl)
library(ggtree)
library(stringr)
library(GThomsonThesis)

###########################################################
### Data
###########################################################
legumes <- c("Medicago tuncatula", "Medicago sativa", "Pisum sativa", "Phaseolus vulgaris", 
             "Glycine max", "Lotus japonicus", "Cicer arietinum", "Vicia faba", 
             "Lupinus angustifolius", "Vigna angularis", "Vigna unguiculata", 
             "Vigna radiata", "Cajanus cajan")
resolved_names <- tnrs_match_names(legumes)

###########################################################
### Tree
###########################################################
tr <- tol_induced_subtree(ott_ids=ott_id(resolved_names))

tree <- groupClade(tr, node=c(15, 19))

temp <- str_replace_all(tree$tip.label, "_", " ") %>%
  str_split("ott") %>%
  unlist() %>%
  str_trim()
tree$tip.label <- temp[seq(1,24,2)]

tree_draw <- ggtree(tree,size=1.5) + 
  geom_tiplab(fontface=3, size=8)  + 
  xlim(0, 10) + 
  geom_tippoint(color=g_colours[2], size=3) + 
  geom_cladelabel(node=15, label="Phaseoloid", offset = 2.75, barsize=1.5, angle=90, fontsize=8, hjust='center', offset.text=.3) +
  geom_cladelabel(node=19, label="Gelegoid", offset = 2.75, barsize=1.5, angle=90, fontsize=8, hjust='center', offset.text=.3)
tree_draw
