###########################################################
### Ch5 - Script 2 - FT tree
###########################################################

###########################################################
### Packages
###########################################################
library(here)
library(tidyverse)

library(GThomsonThesis)
library(ggtree)
library(ggpubr)

###########################################################
### Data
###########################################################

# Load tree data
# FT_tree <- read.tree(here("Data/Alignments/FT_tree.newick"))
FT_tree <-read.tree(here("Protein alignment consensus tree.newick"))

FT_tree$node.label <- ifelse(nchar(FT_tree$node.label) == 0, NA,  round(as.numeric(FT_tree$node.label), 2))
###########################################################
### FT-like gene tree
###########################################################
# Full tree

activators = c(1, 24, 25, 30, 31, 34, 35, 38, 41)
repressor = c(8, 10, 16, 17)

groupClade(ggtree(FT_tree, layout="circular", branch.length="none", size=2), node=c(58, 66, 77)) +
  geom_tiplab2(color="black", hjust = -0.25, size = 5) +
  aes(color=group) + 
  scale_color_manual(values=c('#acacac', g_colours[c(2,3,5)])) +
  geom_tippoint(aes(subset=(node %in% activators)), alpha=1, colour = g_colours[8], size = 5) +
  geom_tippoint(aes(subset=(node %in% repressor)), alpha=1, colour = g_colours[10], fill = g_colours[10], size = 5, shape=23) +
  geom_nodelab(size = 4, label.padding = unit(0.15, "lines"), geom = "label", colour = "black")

ggsave('FT_tree.pdf', width = 341, height = 276, units = 'mm')
