###########################################################
### Ch1 - Script 2 - Saturation graph
###########################################################

###########################################################
### Packages
###########################################################
library(tidyverse)
library(GThomsonThesis)

###########################################################
### Theme
###########################################################
theme_set(my_theme())

###########################################################
### Saturation graph
###########################################################
data_frame(series =  c("0.5 kb", 
                       "1 kb", 
                       "1.6 kb", 
                       "3.5 kb", 
                       "3 kb", 
                       "4 kb", 
                       "5 kb")) %>% 
  mutate(size = str_extract(series, "[^ ]+") %>% 
           as.numeric()) %>% 
  mutate(sim = map(size, ~ data_frame(N = seq(1, 2e+06, 100),
                                      value = 1 - (1 - ( .x / 113100 )) ^ (0.573 * 0.786 * seq(1, 2e+06, 100) ) ))) %>% 
  select(series, sim) %>%
  unnest(sim) %>% 
  
  ggplot(aes(x = N, y = value, colour = series)) + 
  geom_line(size = 2, alpha = 0.5) +
  scale_colour_manual(values = rev(g_colours[c(1:5, 8, 9)])) +
  scale_y_continuous(expand=c(0,0)) +
  scale_x_continuous(expand=c(0.01,0), labels = scales::comma) +
  labs(x= expression(paste("Number of ", italic(Tnt1), " inserts")), 
       y="Probability of Saturation") +
  geom_vline(xintercept = c(542500, 1410500), colour= "black", 
             size = 1.5, alpha = 0.8, linetype = "longdash") +
  theme(legend.position = c(0.85, 0.32),
        legend.text = element_text(size = 22),
        legend.key.size = unit(1.75, 'lines'),
        axis.text = element_text(size = 22),
        axis.title.x = element_text(size = 30, 
                                    margin = margin(t = 20, r = 0, b = 0, l = 0)),
        axis.title.y = element_text(size = 30)) 


ggsave("Ch1_saturation_graph.pdf", width = 339, height = 197, units = "mm")

